@@ -11,7 +11,7 @@ Note
   You must have NLOpt installed on your machine to run this.
   Installing NLOpt basically entailed
     1.  Download the tar.gz
-    2.  Extract the tar bar
+    2.  Extract the tar ball
     3.  cd into trunk of folder
     4.  ./configure
     5.  make
@@ -40,31 +40,31 @@ Note
 
 int opt_nlopt(void *my_func_data,size_t num_func_param,double *ub,double *lb,double *minf,double *fittedpar,gsl_matrix *Hessian_mat,gsl_matrix *inv_Hessian_mat,double *xtol_rel, double *stopval, double *ftol_rel, double *ftol_abs, int *maxeval, double *maxtime)
 {
-    MYPRINT("Optimization function called.\n");
-    nlopt_opt opt;
-    //opt = nlopt_create(NLOPT_LD_MMA, num_func_param);
-    //opt = nlopt_create(NLOPT_LN_NELDERMEAD, num_func_param);
-    opt = nlopt_create(NLOPT_LD_SLSQP, num_func_param); /* algorithm and dimensionality */
-    nlopt_set_upper_bounds(opt, ub);
-    nlopt_set_lower_bounds(opt, lb);
-    nlopt_set_min_objective(opt, myfunc_wrapper,my_func_data);	
-    nlopt_set_xtol_rel(opt, * xtol_rel);
-    //DYNRPRINT(true, "stopping value: %lu\n", (long unsigned int) *stopval);
-    //if(*stopval==-9999){
-    	nlopt_set_stopval(opt, -HUGE_VAL);
-    //} else{
-    //	nlopt_set_stopval(opt, * stopval);
-    //}
-    nlopt_set_ftol_rel(opt, * ftol_rel);
-    nlopt_set_ftol_abs(opt, * ftol_abs);
-    nlopt_set_maxeval(opt, * maxeval);
-    nlopt_set_maxtime(opt, * maxtime);
-    //nlopt_set_initial_step(opt, NULL);
-    /*MYPRINT("Set maxeval option to %d\n", * maxeval);
-    MYPRINT("Set maxtime option to %f\n", * maxtime);*/
-    /*MYPRINT("Set ftol_rel to  %f\n", *ftol_rel);*/
+	MYPRINT("Optimization function called.\n");
+	nlopt_opt opt;
+	//opt = nlopt_create(NLOPT_LD_MMA, num_func_param);
+	//opt = nlopt_create(NLOPT_LN_NELDERMEAD, num_func_param);
+	opt = nlopt_create(NLOPT_LD_SLSQP, num_func_param); /* algorithm and dimensionality */
+	nlopt_set_upper_bounds(opt, ub);
+	nlopt_set_lower_bounds(opt, lb);
+	nlopt_set_min_objective(opt, neg_log_like_with_grad, my_func_data);	
+	nlopt_set_xtol_rel(opt, * xtol_rel);
+	//DYNRPRINT(true, "stopping value: %lu\n", (long unsigned int) *stopval);
+	//if(*stopval==-9999){
+	nlopt_set_stopval(opt, -HUGE_VAL);
+	//} else{
+	//	nlopt_set_stopval(opt, * stopval);
+	//}
+	nlopt_set_ftol_rel(opt, * ftol_rel);
+	nlopt_set_ftol_abs(opt, * ftol_abs);
+	nlopt_set_maxeval(opt, * maxeval);
+	nlopt_set_maxtime(opt, * maxtime);
+	//nlopt_set_initial_step(opt, NULL);
+	/*MYPRINT("Set maxeval option to %d\n", * maxeval);
+	MYPRINT("Set maxtime option to %f\n", * maxtime);*/
+	/*MYPRINT("Set ftol_rel to  %f\n", *ftol_rel);*/
 	
-    int status=nlopt_optimize(opt, fittedpar, minf);
+	int status=nlopt_optimize(opt, fittedpar, minf);
 	
 	nlopt_destroy(opt);
 	
